summaryrefslogtreecommitdiffstats
path: root/qtruby/rubylib/examples/qt-examples/checklists/checklists.rb
diff options
context:
space:
mode:
Diffstat (limited to 'qtruby/rubylib/examples/qt-examples/checklists/checklists.rb')
-rw-r--r--qtruby/rubylib/examples/qt-examples/checklists/checklists.rb12
1 files changed, 6 insertions, 6 deletions
diff --git a/qtruby/rubylib/examples/qt-examples/checklists/checklists.rb b/qtruby/rubylib/examples/qt-examples/checklists/checklists.rb
index 458dc127..9c428c12 100644
--- a/qtruby/rubylib/examples/qt-examples/checklists/checklists.rb
+++ b/qtruby/rubylib/examples/qt-examples/checklists/checklists.rb
@@ -55,8 +55,8 @@ class CheckLists < TQt::Widget
copy1 = TQt::PushButton.new(' -> ', self)
tmp.addWidget(copy1)
copy1.setMaximumWidth(copy1.sizeHint.width)
- # connect the SIGNAL clicked() of the pushbutton with the SLOT copy1to2()
- connect(copy1, SIGNAL('clicked()'), self, SLOT('copy1to2()'))
+ # connect the TQ_SIGNAL clicked() of the pushbutton with the TQ_SLOT copy1to2()
+ connect(copy1, TQ_SIGNAL('clicked()'), self, TQ_SLOT('copy1to2()'))
# another widget for layouting
vbox2 = TQt::VBoxLayout.new(lay)
@@ -79,8 +79,8 @@ class CheckLists < TQt::Widget
copy2 = TQt::PushButton.new(' -> ', self)
lay.addWidget( copy2 )
copy2.setMaximumWidth(copy2.sizeHint.width)
- # ...and connect its clicked() SIGNAL to the copy2to3() SLOT
- connect(copy2, SIGNAL('clicked()'), self, SLOT('copy2to3()'))
+ # ...and connect its clicked() TQ_SIGNAL to the copy2to3() TQ_SLOT
+ connect(copy2, TQ_SIGNAL('clicked()'), self, TQ_SLOT('copy2to3()'))
tmp = TQt::VBoxLayout.new(lay)
tmp.setMargin(5)
@@ -90,7 +90,7 @@ class CheckLists < TQt::Widget
tmp.addWidget(@label)
end
- # SLOT copy1to2()
+ # TQ_SLOT copy1to2()
#
# Copies all checked ListViewItems from the first ListView to
# the second one, and inserts them as Radio-ListViewItem.
@@ -121,7 +121,7 @@ class CheckLists < TQt::Widget
end
- # SLOT copy2to3()
+ # TQ_SLOT copy2to3()
#
# Copies the checked item of the second ListView into the
# Label at the right.